import { Divider, IconButton, TableCell, TableRow, Tooltip } from "@mui/material";
import moment from "moment";
import { memo, useMemo } from "react";
import DeleteButton from "../../../../UI/DeleteButton/DeleteButton";
import { Edit } from "@mui/icons-material";
import { useSelector } from "react-redux";
import CalendarMonthIcon from '@mui/icons-material/CalendarMonth';
import { Box } from "@mui/system";

function UsersTasksRow({ row, deleteTaskHandler, calendarOpen }) {
  const user = useSelector((state) => state.users.user);

  const dateTimeTasks = useMemo(() => {
    if (row.dateTimeTasks.length === 1) {
      const date = moment(row.dateTimeTasks[0].dateTimeStart).utc().format('DD.MM')
      const start = moment(row.dateTimeTasks[0].dateTimeStart).utc().format('HH:mm')
      const end = moment(row.dateTimeTasks[0].dateTimeDue).utc().add(1, 'minutes').format('HH:mm')
      const diff = parseInt(end.split(':')[0]) - parseInt(start.split(':')[0])
      return <Box sx={{ width: '90%', display: 'flex' }}>

        <Box>
          {`${date} (${start} - ${end})`}
          <Divider sx={{ opacity: 0 }} />
          {`часы: ${diff}`}
        </Box>

        {user.id === row?.executor?.id ?
          <Tooltip title="Перейти в календарь">
            <IconButton
              sx={{ marginLeft: '5px' }}
              onClick={() => { calendarOpen(row)}}
            >
              <CalendarMonthIcon />
            </IconButton>
          </Tooltip>
          : null
        }

      </Box>
    } else {
      return null
    }
  }, [user.id, calendarOpen, row])

  return (<>
    <TableRow
      hover
      key={row.id}
    >
      <TableCell sx={{ width: '4%' }}>{row.priority ? row.priority : null}</TableCell>
      <TableCell sx={{ width: '10%' }}>{moment(row.createdAt).format('DD.MM.YYYY')}</TableCell>
      <Tooltip title={row.description}>
        <TableCell sx={{ width: '25%', overflow: 'hidden', textOverflow: 'ellipsis' }}>
          {row.title}
        </TableCell>
      </Tooltip>
      <TableCell sx={{ width: '10%' }}>{row.projectTitle}</TableCell>
      <TableCell sx={{ width: '8%' }}>{row.executorName}</TableCell>
      <TableCell sx={{ width: '8%' }}>{row.authorName}</TableCell>

      <TableCell sx={{ width: '15%' }}>
        {dateTimeTasks}
      </TableCell>

      <TableCell sx={{ width: '10%' }}>{row.dateTimeDeadLine ? moment(row.dateTimeDeadLine).utc().format('DD.MM.YYYY HH:MM') : null}</TableCell>
      <TableCell sx={{ width: '7%' }}>{row.accomplish}</TableCell>
      <TableCell size='medium' sx={{ width: '5%', position: 'relative' }}>
        {user.id === row.author.id ?
          <>
            <Edit sx={{ position: 'absolute', left: -10 }} />
            <DeleteButton onClick={() => { deleteTaskHandler(row.id) }} />
          </>
          :
          <Edit />
        }
      </TableCell>
    </TableRow>
  </>);
}

export default memo(UsersTasksRow)